macroscript MigrateR3Colors category:"Bobo_s Tools"
(
-------------------------------------------------------------------------------
--   File:			MigrateR3Colors
--	 Version:		v0.3
--	 Started:       08/16/2000
--	 Last Modified: 11/14/2000
--   Description:	Transfers Colors from MAX R3 .CUI files to Magma .CLR Files.
--	 Code by:		Borislav Petrov [Boboland]		bobo@email.archlab.tuwien.ac.at
--	 Web:			http://www.gfxcentral.com/bobo/
-------------------------------------------------------------------------------
--	NOTES: 
--	*Grid Intensity does not transfer correctly.
--  *No Loading of the resulting CLR file yet.
--  *This version is compatible with Build M045 and higher ONLY! 
--	Older versions of the .CLR files will not be handled correctly.
--	*This script will work with the English MAX version only. 
-------------------------------------------------------------------------------

global migratecolors_floater

local purge_spaces

rollout migratecolors_rollout "Migrate R3 Colors"
(

group "[1.] Select Color Template"
(
button pick_template ">Select MAX R4 .CLR File as Color Template" align:#right width:300 height:30
edittext template_path text:"" align:#right fieldwidth:300

label r4_label01 " MAX R4 provides more customizable color options than R3. They" align:#left
label r4_label02 " are saved in a separate .CLR file. The Template will be used to:"  align:#left
label r4_label04 "    A) Read the color names to be migrated - the corresponding" align:#left
label r4_label05 "        color definitions will be read from the R3 CUI if existing."  align:#left
label r4_label06 "    B) Read the existing R4 colors when no corresponding R3" align:#left
label r4_label07 "        color can be located in the R3 CUI file." align:#left
label r4_label08 " .CLR files are located in the \UI directory of MAX R4." align:#left

)

group "[2.] Select Color Source"
(
button pick_source  ">Select MAX R3 .CUI File as Color Source" align:#right width:300 height:30
edittext source_path text:"" align:#right fieldwidth:300
label r3_label01 " MAX R3 stores color options in the Custom User Interface" align:#left
label r3_label02 " (.CUI) file. This file will be used to read the existing" align:#left
label r3_label03 " color values of UI elements common in both R3 and R4." align:#left
label r3_label08 " .CUI files are located in the \UI directory of MAX R3.x" align:#left

)

group "[3.] Final R4 Color File"
(
edittext final_path text:"" align:#right fieldwidth:300
label r324_label01 " The result of the Color Migration will be saved in a" align:#left
label r324_label02 " MAX R4 Color File (.CLR). It will contain both colors" align:#left
label r324_label03 " from the Template File and the Color Source." align:#left
label r324_label04 " Its name will be the same as the R3 CUI name, but with" align:#left
label r324_label05 " the suffix \"324\" (R3-to-R4)." align:#left
)

group "[4.] Load Resulting Color File"
(
checkbutton load_result "Load the Resulting Color File After Migration" width:300 height:30 highlightcolor:(color 200 255 200) checked:true
)

group "[5.] Perform Migration"
(
button migrate_go "MIGRATE COLORS" width:300 height:30
label mig_label01 " The progress of the Color Migration will be reported in detail" align:#left
label mig_label02 " in the MAXScript Listener window." align:#left

)



on pick_template pressed do
(
open_R4_File = getOpenFileName caption:"Select MAX R4 Colors File" types:"Colors File (*.clr)|*.clr" 
if open_R4_File  != undefined then 
	(
	template_path.text = open_R4_File  
	)
)


on pick_source pressed do
(
open_R3_File = getOpenFileName caption:"Select MAX R3 CUI File" types:"CUI File (*.cui)|*.cui"
if open_R3_File != undefined then 
	(
	source_path.text = open_R3_File 
	final_path.text = (GetDir #ui +"\\"+ (getfilenamefile open_R3_File) +"_324.clr")
	)
)


on migrate_go pressed do
(
max3_colors = openfile source_path.text
if max3_colors != undefined then
(
max4_colors = openfile template_path.text
if max4_colors != undefined then
(
format "Starting Color Table Conversion...\n"

out_file = final_path.text
max324 = createfile out_file
format "Writing To File %\n" out_file

fn purge_spaces old_name =
(
	new_name = ""
	for i = 1 to old_name.count do
	(
	if substring old_name i 1 != " " then new_name += substring old_name i 1
	)
new_name
)

fn get_r3_color max3_colors name_string col_str =
(
	seek max3_colors 1
	skiptostring max3_colors "[Colors]"

	R3_name_string = purge_spaces name_string 
	case R3_name_string of
	(
	"UnselectedTabs": R3_name_string = "UnSelTab"
	"Terminator": R3_name_string = "IKTerminator"
	"JointLimits": R3_name_string = "JointLimitUnsel"
	"SelectedJointLimits": R3_name_string = "JointLimitSel"
	"See-Through": R3_name_string = "X-Ray"
	"SubSelectionHard": R3_name_string = "SubSelection"
	"SubSelectionMedium": R3_name_string = "SubSelection"
	"SafeframeLive": R3_name_string = "SFLive"
	"SafeframeAction": R3_name_string = "SFAction"
	"SafeframeTitle": R3_name_string = "SFTitle"	
	"SafeframeUser": R3_name_string = "SFUser"	
	"ViewportLabel": R3_name_string = "VPLabel"	
	"InactiveViewportLabel": R3_name_string = "VPInactive"	
	"ArcballHighlight": R3_name_string = "ArcballHilite"
	"ViewportClipping": R3_name_string = "VptClipping"
	"TransformGizmoX": R3_name_string = "XTransformGizmo"
	"TransformGizmoY": R3_name_string = "YTransformGizmo"
	"TransformGizmoZ": R3_name_string = "ZTransformGizmo"	
	"CameraClipping": R3_name_string = "CameraClip"
	
	"LightNearRangeStart": R3_name_string = "LightNearStart"
	"LightNearRangeEnd": R3_name_string = "LightNearEnd"	
	"LightFarRangeStart": R3_name_string = "LightFarStart"
	"LightFarRangeEnd": R3_name_string = "LightFarEnd"
	"LightDecayStart": R3_name_string = "LightDecayRadius"	

	"TrajectoryFrames1": R3_name_string = "TrajTic1"	
	"TrajectoryFrames2": R3_name_string = "TrajTic2"	
	"TrajectoryFrames3": R3_name_string = "TrajTic3"	

	"Ghost(Before)": R3_name_string = "GhostBefore"	
	"Ghost(After)": R3_name_string = "GhostAfter"	
	"12-FieldGrid": R3_name_string = "12FieldGrid"	
	
	"NURBSControlVertex": R3_name_string = "NURBSCV"	
	"NURBSConPoint": R3_name_string = "NURBSCP"	
	"NURBSFitPoint": R3_name_string = "NURBSFP"	
	"NURBSDepObject": R3_name_string = "NURBSDepObj"	
	"NURBSErrorObject": R3_name_string = "NURBSErrorObj"	

	"SVWindowBkg": R3_name_string = "SVWinBk"	
	"SVNodeBkg": R3_name_string = "SVNodeBk"	
	"SVSelectedNodeBkg": R3_name_string = "SVSelNodeBk"	
	"SVSub-AnimLine": R3_name_string = "SVSubanimLine"	
	
	"SVMapNodeBkg": R3_name_string = "SVMapBk,"	
	"SVMaterialNodeBkg": R3_name_string = "SVMaterialBk,"	
	"SVModifierNodeBkg": R3_name_string = "SVModifierBk,"	
	"SVControllerNodeBkg": R3_name_string = "SVControllerBk,"	
	"SVSystemNodeBkg": R3_name_string = "SVSystemBk,"	

	"SVHelperNodeBkg": R3_name_string = "SVHelperBk,"
	"SVShapeNodeBkg": R3_name_string = "SVShapeBk,"
	"SVCameraNodeBkg": R3_name_string = "SVCameraBk,"
	"SVLightNodeBkg": R3_name_string = "SVLightBk,"
	"SVGeometryNodeBkg": R3_name_string = "SVGeomobjectBk,"
	"SVUnfoldChildrenButton": R3_name_string = "SVUnfoldButton,"		
	"SVLabel": R3_name_string = "SVText"
	"SVSelectedLabel": R3_name_string = "SVSelText"	
	
	"AtmosphericApparatuses": R3_name_string = "AtmosApparatus"	

	)
	a = skiptostring max3_colors (R3_name_string+"=")
	if a != undefined then
	(
	try
	(
		if R3_name_string == "GridIntensity" then
		(
		format "MIGRATING % to %..." R3_name_string name_string
		str = readline max3_colors
		col_val = execute ("point3 "+str + " "+str + " " + str)
		new_col_val = (col_val.z as integer * 256^2)+(col_val.y as integer* 256) + col_val.x as integer
		col_str = new_col_val as string
		format "\n" 
		)
		else
		(
		format "MIGRATING % to %..." R3_name_string name_string
		str = readline max3_colors
		col_val = execute ("point3 "+str)
		col_val = col_val * 255
		new_col_val = (col_val.z as integer * 256^2)+(col_val.y as integer* 256) + col_val.x as integer
		col_str = new_col_val as string
		format "\n" 
		)

	)
	catch
	(
	format "Skipping!\n"
	)
	)
	else
	(
	format "COPYING COLOR FROM TEMPLATE: % \n" name_string  

	)
col_str	
)

while not eof max4_colors do
(
in_str = readline max4_colors

if findstring in_str "useStandardColors=" != undefined then 
	(
	in_str = "useStandardColors=1"
	format "Use Windows Colors Enabled.\n"
	)

if findstring in_str "enabledSatScale=" != undefined then in_str = "enabledSatScale=100"
if findstring in_str "enabledValueScale=" != undefined then in_str = "enabledValueScale=100"
if findstring in_str "enabledAlphaScale=" != undefined then in_str = "enabledAlphaScale=100"
if findstring in_str "enabledInvertImage=" != undefined then in_str = "enabledInvertImage=0"

if findstring in_str "disabledSatScale=" != undefined then in_str = "enabledSatScale=5"
if findstring in_str "disabledValueScale=" != undefined then in_str = "enabledValueScale=33"
if findstring in_str "disabledAlphaScale=" != undefined then in_str = "enabledAlphaScale=33"
if findstring in_str "disabledInvertImage=" != undefined then in_str = "disabledInvertImage=0"

if findstring in_str "Color_" != undefined then
	(
	full_col_str = copy in_str
	col_str = substring full_col_str ((findstring full_col_str "=")+1) 100
	old_col_str = copy col_str
	in_str = readline max4_colors
	start_pos = findstring in_str "\""
	name_string = substring in_str (start_pos+1) 100
	end_pos = findstring name_string "\""
	name_string = substring name_string 1 (end_pos-1)
	
	col_str = get_r3_color max3_colors name_string col_str
	col_prefix = (substring full_col_str 1 (findstring full_col_str "="))
	format "%%\n" col_prefix col_str to:max324
	format "Old Color Code: % -> New Color Code: % \n" old_col_str col_str 
	)

format "%\n" in_str to:max324
)--end while

close max3_colors
close max4_colors
close max324

if load_result.checked then colorMan.loadColorFile (filenamefrompath (final_path.text))

format "Ready!\n\n"
)--end if
else
(
format "Invalid Template File. Aborting...\n\n" 
)
)--end if
else
(
format "No or invalid MAX R3 CUI File Selected. Aborting...\n\n" 
)
)--end on go
)--end roll

try(closerolloutfloater migratecolors_floater)catch()
migratecolors_floater = newrolloutfloater "Migrate R3 Colors" 360 720 100 100
addrollout migratecolors_rollout migratecolors_floater 

test_max4_colors = getFiles (GetDir #ui +"\\MaxColors.clr")
if test_max4_colors.count == 1 then
	(
	migratecolors_rollout.template_path.text = test_max4_colors[1]
	)

)--end script